﻿
Function Get-ArchitectureString {

# Determine bitness of OS and load appropriate files.

  $Arch=(Get-CimInstance win32_operatingsystem).OSArchitecture
  if ($Arch -eq '32-Bit') {
     Return [string]' (x86)'
  }
  Else { 
     Return [string]'amd64'
  }
} #End Function Get-ArchitectureString

Function Test-WindowsADK {

<# Test to see if the ADK is installed in the Default Location!
   64-Bit = C:\Program Files (x86)\...
   32-Bit = C:\Program Files\...
#>
  $SubFolder = Get-ArchitectureString
  Write-Host $SubFolder
  If ($SubFolder -eq 'amd64') {
    $SubFolder = ' (x86)'
  }
  Else {
    $SubFolder = ''
  }

  Write-Host $SubFolder

  Return $(Test-Path -Path (
            "C:\Program Files$($SubFolder)\Windows Kits\10\" +
            "Assessment and Deployment Kit" +
            "\Windows Preinstallation Environment"))

                    
} #End Function Test-WindowsADK

#----- Setup Working Environment -----

If (-not(Test-WindowsADK)) {
  Write-Host "Windows ADK not Detected!`n`nPlease Install..."
  Exit
}

$WinADK="C:\Program Files (x86)\Windows Kits\10\" +
        "Assessment and Deployment Kit" +
        "\Windows Preinstallation Environment\" +
        "$(Get-ArchitectureString)"
$WinPETemp='G:\TempPE'

New-Item -ItemType Directory -Path "$($WinPETemp)\Media" -force
$CIArgs = @{path        = "$($WinAdk)\en-us\winpe.wim" 
            Destination = "$($WinPETemp)\Media\boot.wim"}
Copy-Item @CIArgs
New-Item -ItemType Directory -Path "$($WinPETemp)\Mount" –Force

#----- Mount the WinPE WIM file for Editing -----

$MTArgs = @{ImagePath = "$($WinPETemp)\Media\boot.wim" 
            Index     = 1 
            path      = "$($WinPETemp)\Mount"}
Mount-WindowsImage @MTArgs

#--- Packages List - PowerShell, Storage, and DISM cmdlets --#
$PkgList = @(
    "WinPE-WMI.cab", 
    "en-us\WinPE-WMI_en-us.cab", 
    "WinPE-NetFx.cab", 
    "en-us\WinPE-NetFx_en-us.cab", 
    "WinPE-Scripting.cab", 
    "en-us\WinPE-Scripting_en-us.cab", 
    "WinPE-PowerShell.cab", 
    "en-us\WinPE-PowerShell_en-us.cab", 
    "WinPE-DismCmdlets.cab", 
    "en-us\WinPE-DismCmdlets_en-us.cab", 
    "WinPE-EnhancedStorage.cab", 
    "en-us\WinPE-EnhancedStorage_en-us.cab", 
    "WinPE-StorageWMI.cab", 
    "en-us\WinPE-StorageWMI_en-us.cab") 

 ForEach ($Pkg in $PkgList) {
 $AWPArgs = @{PackagePath = "$($WinAdk)\Winpe_OCS\$($Pkg)"
              Path        = "$($WinPETemp)\Mount"
              IgnoreCheck = $true }

 Add-WindowsPackage @AWPArgs 

 } #End ForEach ($Pkg...

<#
  Add your modifications now...
  Such as Directory for User Scripts, 
  Registry Modifications, specifically Powershell 
  Execution Policy
#>

#--- User Script Directory ---
$NIArgs = @{ItemType = 'Directory' 
            Path     = "$($WinPETemp)\Mount\Users\Scripts"}
New-Item @NIArgs

#--- Add User Scripts to Directory ---

$Scripts = @("Function-PromptForInteger.ps1",
             "GetDotNetVersionsInstalled.ps1")

ForEach ($FN in $Scripts) {
  $CIArgs = @{Path        = "G:\BEKDocs\Scripts\$FN" 
              Destination = "$($WinPETemp)\Mount\Users\Scripts"}
  Copy-Item @CIArgs
}

#--- Modify PowerShell Execution Policy in WIM Registry ---

reg load "HKLM\WimPE" "$($WinPETemp)\Mount\Windows\System32\config\software"
$RegPath = "HKLM:\WimPE\SOFTWARE\Microsoft\PowerShell\1\ShellIds" +
           "\Microsoft.Powershell\"
$NIArgs = @{Path  = $RegPath 
            Name  = 'ExeutionPolicy' 
            Value = "RemoteSigned"
            PropertyType = 'DWORD'
            Force = $True}
New-ItemProperty @NIArgs
reg unload "HKLM\WimPE"

#----- DisMount the Modified WinPE WIM File -----

Dismount-WindowsImage -path "$($WinPETemp)\Mount" -Save

#----- Make a Backup of the Modified WIM file -----

$Destination='G:\Pewim'
New-Item -Path $Destination -ItemType Directory –Force

$CIArgs = @{Path        = "$($WinPETemp)\Media\boot.wim" 
            Destination = "$($Destination)\"}
Copy-Item @CIArgs